@@ -1,10 +1,11 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/mga/mga_halmod.c,v 1.1 2000/12/06 15:35:21 eich Exp $ */
+/* $XFree86$ */
 #include "xf86Module.h"
+#include "mga_vendor.h"
 
 #ifdef XFree86LOADER
 
 #define HAL_MAJOR_VERSION 4
-#define HAL_MINOR_VERSION 1
+#define HAL_MINOR_VERSION 2
 #define HAL_PATCHLEVEL 0
 
 static MODULESETUPPROTO(halSetup);
@@ -12,10 +13,10 @@ static MODULESETUPPROTO(halSetup);
 static XF86ModuleVersionInfo halVersRec =
 {
 	"mga_hal",
-	MODULEVENDORSTRING,
+	VENDORSTRING,
 	MODINFOSTRING1,
 	MODINFOSTRING2,
-	XF86_VERSION_CURRENT,
+	XORG_VERSION_CURRENT,
 	HAL_MAJOR_VERSION, HAL_MINOR_VERSION, HAL_PATCHLEVEL,
 	ABI_CLASS_VIDEODRV,			/* This is a video driver */
 	ABI_VIDEODRV_VERSION,
